@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::Init;
 {
-  $Dist::Zilla::Plugin::Git::Init::VERSION = '2.011';
+  $Dist::Zilla::Plugin::Git::Init::VERSION = '2.012';
 }
 # ABSTRACT: initialize git repository on dzil new
 
@@ -40,6 +40,12 @@ has commit_message => (
     default => 'initial commit',
 );
 
+has commit => (
+    is      => 'ro',
+    isa     => 'Bool',
+    default => 1,
+);
+
 has remotes => (
   is   => 'ro',
   isa  => 'ArrayRef[Str]',
@@ -69,7 +75,8 @@ sub after_mint {
     }
 
     $git->add("$opts->{mint_root}");
-    $git->commit({message => _format_string($self->commit_message, $self)});
+    $git->commit({message => _format_string($self->commit_message, $self)})
+      if $self->commit;
     foreach my $remoteSpec (@{ $self->remotes }) {
       my ($remote, $url) = split ' ', _format_string($remoteSpec, $self), 2;
       $self->log_debug("Adding remote $remote as $url");
@@ -89,7 +96,7 @@ Dist::Zilla::Plugin::Git::Init - initialize git repository on dzil new
 
 =head1 VERSION
 
-version 2.011
+version 2.012
 
 =head1 SYNOPSIS
 
@@ -97,6 +104,7 @@ In your F<profile.ini>:
 
     [Git::Init]
     commit_message = initial commit  ; this is the default
+    commit = 1                       ; this is the default
     remote = origin git@github.com:USERNAME/%{lc}N.git ; no default
     config = user.email USERID@cpan.org  ; there is no default
 
@@ -114,6 +122,10 @@ The plugin accepts the following options:
 =item * commit_message - the commit message to use when checking in
 the newly-minted dist. Defaults to C<initial commit>.
 
+=item * commit - if true (the default), commit the newly-minted dist.
+If set to a false value, add the files to the Git index but don't
+actually make a commit.
+
 =item * config - a config setting to make in the repository.  No
 config entries are made by default.  A setting is specified as
 C<OPTION VALUE>.  This may be specified multiple times to add multiple entries.
